=======
Credits
=======

Development Lead
----------------

* Rick van Hattem (Wolph) <wolph@wol.ph>

Contributors
------------

None yet. Why not be the first? (since 2015-07-11, new format)

A more up to date list can be found here: 
https://github.com/WoLpH/mt940/graphs/contributors
